pub fn load_manifest(path: &Path) -> Result<CompetitorManifest, BenchmarkError>Expand description
Parses a competitor corpus manifest.
Errors
Returns an error when the manifest cannot be read or parsed.
pub fn load_manifest(path: &Path) -> Result<CompetitorManifest, BenchmarkError>Parses a competitor corpus manifest.
Returns an error when the manifest cannot be read or parsed.