run_competitor_suite

Function run_competitor_suite 

pub fn run_competitor_suite(
    config: &SampleConfig,
) -> Result<CompetitorSuiteReport, BenchmarkError>
Loads the default manifest and runs the default vendored competitor suite.

Errors

Returns an error when the manifest cannot be read or parsed.