run_competitor_suite_from_paths

Function run_competitor_suite_from_paths 

pub fn run_competitor_suite_from_paths(
    manifest_path: &Path,
    corpora_root: &Path,
    config: &SampleConfig,
) -> Result<CompetitorSuiteReport, BenchmarkError>
Loads a manifest and runs a vendored competitor suite from explicit paths.

Errors

Returns an error when the manifest cannot be read or parsed.