pub enum RuleKind {
Normal,
Atomic,
Silent,
Token,
}Expand description
How a rule participates in parsing.
Variants
Normal
A normal rule that participates in the parse tree.
Atomic
An atomic rule whose inner expression is treated as an indivisible token.
Silent
A silent rule that can be omitted from visible parse output.
Token
A token-level rule.
Implementations