pub fn canonical_grammar_format(format: &str) -> Option<&'static str>Expand description
Canonicalizes a grammar format label to one of GRAMMAR_FORMATS.
pub fn canonical_grammar_format(format: &str) -> Option<&'static str>Canonicalizes a grammar format label to one of GRAMMAR_FORMATS.