pub enum GrammarImportError {
Parse {
format: GrammarFormat,
message: String,
},
Unsupported {
format: GrammarFormat,
construct: String,
},
}Expand description
Error raised while importing an external grammar notation.
Variants
Parse
The source text could not be parsed or validated as the requested format.
Fields

format: GrammarFormatGrammar format being imported.
Unsupported
The importer parsed the input but cannot lower this construct yet.
Fields

format: GrammarFormatGrammar format being imported.