import_abnf

Function import_abnf 

pub fn import_abnf(text: &str) -> Result<Grammar, GrammarImportError>
Parses Augmented Backus-Naur Form text into the grammar IR.

Errors

Returns GrammarImportError when the ABNF text cannot be parsed, when a parsed construct cannot be represented, or when a non-terminal reference does not resolve to an imported or RFC 5234 core rule.