import_bnf

Function import_bnf 

pub fn import_bnf(text: &str) -> Result<Grammar, GrammarImportError>
Parses classic Backus-Naur Form text into the grammar IR.

Errors

Returns GrammarImportError when the BNF text cannot be parsed, when a parsed construct cannot be represented, or when a non-terminal reference does not resolve to a rule in the imported grammar.