import_pest

Function import_pest 

pub fn import_pest(text: &str) -> Result<Grammar, GrammarImportError>
Parses PEG .pest grammar text into the grammar IR.

Errors

Returns GrammarImportError when the pest grammar cannot be parsed or validated, when a parsed construct cannot be represented in the grammar IR, or when a non-terminal reference does not resolve to a local rule or pest built-in.