import_tree_sitter_json

Function import_tree_sitter_json 

pub fn import_tree_sitter_json(
    text: &str,
) -> Result<Grammar, GrammarImportError>
Parses tree-sitter grammar.json text into the grammar IR.

Errors

Returns GrammarImportError when the JSON cannot be parsed or validated, or when a node type cannot be represented in the grammar IR.