pub struct AptaState {
pub accepting: bool,
pub rejecting: bool,
pub arrival_count: u64,
pub final_count: u64,
}Expand description
One state in an augmented prefix-tree acceptor.
Fields
accepting: boolWhether at least one positive example ends in this state.
rejecting: boolWhether at least one negative example ends in this state.
arrival_count: u64Number of positive examples whose path visits this state.
final_count: u64Number of positive examples ending in this state.