pub enum QueryAuthorization {
Required,
}Expand description
Whether a lowered plan has been authorized for execution.
Parsing and semantic lowering never grant permission to execute a query.
Variants
Required
A consuming engine must still apply its authorization policy.