pub struct LinksEncoder { /* private fields */ }Expand description
Stateful Rust value encoder.
Implementations
Sourceimpl LinksEncoder
impl LinksEncoder
Sourcepub const fn with_network(network: LinkNetwork) -> Self
pub const fn with_network(network: LinkNetwork) -> Self
Creates an encoder that appends to an existing network.
Sourcepub const fn network(&self) -> &LinkNetwork
pub const fn network(&self) -> &LinkNetwork
Returns the underlying network.
Sourcepub fn network_mut(&mut self) -> &mut LinkNetwork
pub fn network_mut(&mut self) -> &mut LinkNetwork
Returns the underlying network mutably.
Sourcepub fn into_network(self) -> LinkNetwork
pub fn into_network(self) -> LinkNetwork
Finishes encoding and returns the network.
Sourcepub fn encode<T: ToLinks + ?Sized>(&mut self, value: &T) -> LinkId
pub fn encode<T: ToLinks + ?Sized>(&mut self, value: &T) -> LinkId
Encodes a value and returns its root link.
Sourcepub fn register_type_shape(&mut self, shape: &RustTypeShape) -> LinkId
pub fn register_type_shape(&mut self, shape: &RustTypeShape) -> LinkId
Registers a queryable Rust type shape and returns its type link.
Sourcepub fn begin_object(&mut self, shape: &RustTypeShape) -> LinkId
pub fn begin_object(&mut self, shape: &RustTypeShape) -> LinkId
Starts an object instance for a Rust type shape.