RustTypeShape

Struct RustTypeShape 

pub struct RustTypeShape { /* private fields */ }
Queryable Rust type declaration shape.

Implementations

Source

impl RustTypeShape

pub fn primitive(name: impl Into<String>) -> Self

Creates a primitive type shape.

pub fn structure<I>(name: impl Into<String>, fields: I) -> Self
where I: IntoIterator<Item = RustFieldShape>,

Creates a struct type shape.

pub fn enumeration<I>(name: impl Into<String>, variants: I) -> Self
where I: IntoIterator<Item = RustFieldShape>,

Creates an enum type shape, using field entries as variants.

pub fn trait_type<I>(name: impl Into<String>, items: I) -> Self
where I: IntoIterator<Item = RustFieldShape>,

Creates a trait type shape, using field entries as required items.

pub fn sequence( name: impl Into<String>, element_type: impl Into<String>, ) -> Self

Creates a sequence container type shape.

pub fn option(name: impl Into<String>, value_type: impl Into<String>) -> Self

Creates an optional-value container type shape.

pub fn map( name: impl Into<String>, key_type: impl Into<String>, value_type: impl Into<String>, ) -> Self

Creates a map container type shape.

pub fn name(&self) -> &str

Rust display name for this type.

pub const fn kind(&self) -> RustTypeKind

Type declaration kind.

pub fn fields(&self) -> &[RustFieldShape]

Declared fields, variants, or trait items.