pub struct MutableNetworkSnapshot { /* private fields */ }Expand description
Editable fork of an immutable network snapshot.
Implementations
Sourceimpl MutableNetworkSnapshot
impl MutableNetworkSnapshot
Sourcepub const fn base_version(&self) -> u64
pub const fn base_version(&self) -> u64
Version this mutable snapshot was forked from.
Sourcepub fn provenance(&self) -> &str
pub fn provenance(&self) -> &str
Human-readable provenance that will be attached when committed.
Sourcepub const fn network(&self) -> &LinkNetwork
pub const fn network(&self) -> &LinkNetwork
Immutable view of the editable network.
Sourcepub fn network_mut(&mut self) -> &mut LinkNetwork
pub fn network_mut(&mut self) -> &mut LinkNetwork
Mutable view of the editable network.
Sourcepub fn commit(self) -> NetworkSnapshot
pub fn commit(self) -> NetworkSnapshot
Commits this mutable snapshot as the next sequential version.
Sourcepub fn commit_as(self, version: u64) -> NetworkSnapshot
pub fn commit_as(self, version: u64) -> NetworkSnapshot
Commits this mutable snapshot with an explicit forward version.