pub struct StructuralDiff { /* private fields */ }Expand description
Changed, added, and removed link identifiers between two network versions.
Implementations
Sourceimpl StructuralDiff
impl StructuralDiff
Sourcepub const fn new(
changed: BTreeSet<LinkId>,
added: BTreeSet<LinkId>,
removed: BTreeSet<LinkId>,
) -> Self
pub const fn new( changed: BTreeSet<LinkId>, added: BTreeSet<LinkId>, removed: BTreeSet<LinkId>, ) -> Self
Creates a structural diff from its changed, added, and removed sets.