LinkStoreQuery

Struct LinkStoreQuery 

pub struct LinkStoreQuery { /* private fields */ }
Implementations

Source

impl LinkStoreQuery

pub const fn new() -> Self

Creates a query that matches every link.

pub const fn with_id(self, id: LinkId) -> Self

Restricts the query to one link id.

pub fn with_references<I>(self, references: I) -> Self
where I: IntoIterator<Item = LinkId>,

Restricts the query to links with exactly these ordered references.

Restricts the query to a link type.

pub fn with_term(self, term: impl Into<String>) -> Self

Restricts the query to links with this term.

pub fn with_language(self, language: impl Into<String>) -> Self

Restricts the query to links with this language label.

pub const fn with_named(self, named: bool) -> Self

Restricts the query to named or anonymous links.