pub struct ReplacementReport { /* private fields */ }Expand description
Result of replacing query-selected links.
Implementations
Sourceimpl ReplacementReport
impl ReplacementReport
Sourcepub fn text_replacements(&self) -> &[TextReplacement]
pub fn text_replacements(&self) -> &[TextReplacement]
Source-text replacements made for captured links.
Sourcepub fn template_errors(&self) -> &[QuasiquoteError]
pub fn template_errors(&self) -> &[QuasiquoteError]
Template rendering errors that prevented replacements.
Sourcepub const fn substitution(&self) -> &SubstitutionReport
pub const fn substitution(&self) -> &SubstitutionReport
Structural substitution result, when the rule delegates to substitution.
Sourcepub fn profile_diagnostics(&self) -> &[LinkId]
pub fn profile_diagnostics(&self) -> &[LinkId]
Diagnostic links created when a language profile rejected a replacement.