pub fn run_competitor_suite(
config: &SampleConfig,
) -> Result<CompetitorSuiteReport, BenchmarkError>Expand description
Loads the default manifest and runs the default vendored competitor suite.
Errors
Returns an error when the manifest cannot be read or parsed.