LinkFlags

Struct LinkFlags 

pub struct LinkFlags { /* private fields */ }
Tree-sitter-compatible parse status flags modeled as link metadata.

Implementations

Source

impl LinkFlags

pub const fn clean() -> Self

Clean link flags.

pub const fn error() -> Self

Flags for an error link.

pub const fn containing_error() -> Self

Flags for a link that contains an error below it.

pub const fn missing() -> Self

Flags for a missing link.

pub const fn extra() -> Self

Flags for an extra/trivia link.

pub const fn is_error(self) -> bool

Whether this link is an error link.

pub const fn has_error(self) -> bool

Whether this link contains an error below it.

pub const fn is_missing(self) -> bool

Whether this link is missing from the source text.

pub const fn is_extra(self) -> bool

Whether this link is extra source trivia.