pub struct LinkFlags { /* private fields */ }Expand description
Tree-sitter-compatible parse status flags modeled as link metadata.
Implementations
Sourceimpl LinkFlags
impl LinkFlags
Sourcepub const fn containing_error() -> Self
pub const fn containing_error() -> Self
Flags for a link that contains an error below it.
Sourcepub const fn is_missing(self) -> bool
pub const fn is_missing(self) -> bool
Whether this link is missing from the source text.