pub struct LinkFlags { /* private fields */ }Expand description
Tree-sitter-compatible parse status flags modeled as link metadata.
Implementations
Sourceimpl LinkFlags
impl LinkFlags
Sourcepub const fn containing_error() -> Self
pub const fn containing_error() -> Self
Flags for a link that contains an error below it.
Sourcepub const fn with_error(self) -> Self
pub const fn with_error(self) -> Self
Returns flags with the error bit enabled.
Sourcepub const fn with_containing_error(self) -> Self
pub const fn with_containing_error(self) -> Self
Returns flags with the containing-error bit enabled.
Sourcepub const fn with_missing(self) -> Self
pub const fn with_missing(self) -> Self
Returns flags with the missing bit enabled.
Sourcepub const fn with_extra(self) -> Self
pub const fn with_extra(self) -> Self
Returns flags with the extra/trivia bit enabled.
Sourcepub const fn is_missing(self) -> bool
pub const fn is_missing(self) -> bool
Whether this link is missing from the source text.