pub trait QueryPredicateHost {
// Required method
fn evaluate(
&self,
predicate: &QueryPredicate,
captures: &QueryCaptures,
network: &LinkNetwork,
) -> bool;
}Expand description
Host hook for evaluating text, regex, semantic, or other predicates.
Required Methods
Sourcefn evaluate(
&self,
predicate: &QueryPredicate,
captures: &QueryCaptures,
network: &LinkNetwork,
) -> bool
fn evaluate( &self, predicate: &QueryPredicate, captures: &QueryCaptures, network: &LinkNetwork, ) -> bool
Returns whether a predicate accepts the current capture set.