pub struct RustTypeShape { /* private fields */ }Expand description
Queryable Rust type declaration shape.
Implementations
Sourceimpl RustTypeShape
impl RustTypeShape
Sourcepub fn structure<I>(name: impl Into<String>, fields: I) -> Selfwhere
I: IntoIterator<Item = RustFieldShape>,
pub fn structure<I>(name: impl Into<String>, fields: I) -> Selfwhere
I: IntoIterator<Item = RustFieldShape>,
Creates a struct type shape.
Sourcepub fn enumeration<I>(name: impl Into<String>, variants: I) -> Selfwhere
I: IntoIterator<Item = RustFieldShape>,
pub fn enumeration<I>(name: impl Into<String>, variants: I) -> Selfwhere
I: IntoIterator<Item = RustFieldShape>,
Creates an enum type shape, using field entries as variants.
Sourcepub fn trait_type<I>(name: impl Into<String>, items: I) -> Selfwhere
I: IntoIterator<Item = RustFieldShape>,
pub fn trait_type<I>(name: impl Into<String>, items: I) -> Selfwhere
I: IntoIterator<Item = RustFieldShape>,
Creates a trait type shape, using field entries as required items.
Sourcepub fn sequence(
name: impl Into<String>,
element_type: impl Into<String>,
) -> Self
pub fn sequence( name: impl Into<String>, element_type: impl Into<String>, ) -> Self
Creates a sequence container type shape.
Sourcepub fn option(name: impl Into<String>, value_type: impl Into<String>) -> Self
pub fn option(name: impl Into<String>, value_type: impl Into<String>) -> Self
Creates an optional-value container type shape.
Sourcepub fn map(
name: impl Into<String>,
key_type: impl Into<String>,
value_type: impl Into<String>,
) -> Self
pub fn map( name: impl Into<String>, key_type: impl Into<String>, value_type: impl Into<String>, ) -> Self
Creates a map container type shape.
Sourcepub const fn kind(&self) -> RustTypeKind
pub const fn kind(&self) -> RustTypeKind
Type declaration kind.
Sourcepub fn fields(&self) -> &[RustFieldShape]
pub fn fields(&self) -> &[RustFieldShape]
Declared fields, variants, or trait items.