pub struct NetworkSnapshot { /* private fields */ }Expand description
Immutable versioned view of a links network.
Implementations
Sourceimpl NetworkSnapshot
impl NetworkSnapshot
Sourcepub fn new(
version: u64,
network: LinkNetwork,
provenance: impl Into<String>,
) -> Self
pub fn new( version: u64, network: LinkNetwork, provenance: impl Into<String>, ) -> Self
Creates an immutable snapshot from a network value.
Sourcepub const fn parent_version(&self) -> Option<u64>
pub const fn parent_version(&self) -> Option<u64>
Parent version when this snapshot was committed from a mutable snapshot.
Sourcepub fn provenance(&self) -> &str
pub fn provenance(&self) -> &str
Human-readable change provenance for this snapshot.
Sourcepub fn network(&self) -> &LinkNetwork
pub fn network(&self) -> &LinkNetwork
Immutable network data held by this snapshot.
Number of immutable snapshot handles sharing the same network value.
Sourcepub fn to_mutable(
&self,
provenance: impl Into<String>,
) -> MutableNetworkSnapshot
pub fn to_mutable( &self, provenance: impl Into<String>, ) -> MutableNetworkSnapshot
Creates an editable snapshot fork from this immutable snapshot.