pub struct LinkStoreQuery { /* private fields */ }Expand description
Query used by LinkStore::search and LinkStore::count.
Implementations
Sourceimpl LinkStoreQuery
impl LinkStoreQuery
Sourcepub fn with_references<I>(self, references: I) -> Selfwhere
I: IntoIterator<Item = LinkId>,
pub fn with_references<I>(self, references: I) -> Selfwhere
I: IntoIterator<Item = LinkId>,
Restricts the query to links with exactly these ordered references.
Sourcepub const fn with_link_type(self, link_type: LinkType) -> Self
pub const fn with_link_type(self, link_type: LinkType) -> Self
Restricts the query to a link type.
Sourcepub fn with_term(self, term: impl Into<String>) -> Self
pub fn with_term(self, term: impl Into<String>) -> Self
Restricts the query to links with this term.
Sourcepub fn with_language(self, language: impl Into<String>) -> Self
pub fn with_language(self, language: impl Into<String>) -> Self
Restricts the query to links with this language label.
Sourcepub const fn with_named(self, named: bool) -> Self
pub const fn with_named(self, named: bool) -> Self
Restricts the query to named or anonymous links.