pub struct TranslationRuleRegistry { /* private fields */ }Expand description
Runtime registry for selecting and replacing active translation rule sets.
Implementations
Sourceimpl TranslationRuleRegistry
impl TranslationRuleRegistry
Sourcepub fn with_statehood_demo() -> Self
pub fn with_statehood_demo() -> Self
Creates a registry containing the statehood demo rule set.
Sourcepub fn with_rule_set(self, rule_set: TranslationRuleSet) -> Self
pub fn with_rule_set(self, rule_set: TranslationRuleSet) -> Self
Returns a copy with a rule set registered.
Sourcepub fn replace_rule_set(&mut self, rule_set: TranslationRuleSet)
pub fn replace_rule_set(&mut self, rule_set: TranslationRuleSet)
Inserts or replaces a rule set. The first registered set becomes active.
Sourcepub fn set_active_rule_set(&mut self, name: &str) -> bool
pub fn set_active_rule_set(&mut self, name: &str) -> bool
Selects the active rule set by name.
Sourcepub fn active_rule_set(&self) -> Option<&TranslationRuleSet>
pub fn active_rule_set(&self) -> Option<&TranslationRuleSet>
Returns the active rule set.
Sourcepub fn rule_set(&self, name: &str) -> Option<&TranslationRuleSet>
pub fn rule_set(&self, name: &str) -> Option<&TranslationRuleSet>
Looks up a rule set by name.