pub struct TranslationRuleSet { /* private fields */ }Expand description
Ordered collection of named translation rules.
Implementations
Sourceimpl TranslationRuleSet
impl TranslationRuleSet
Sourcepub fn rules(&self) -> &[TranslationRule]
pub fn rules(&self) -> &[TranslationRule]
Ordered rules in this set.
Sourcepub fn with_rule(self, rule: TranslationRule) -> Self
pub fn with_rule(self, rule: TranslationRule) -> Self
Returns a copy with one rule appended.
Sourcepub fn add_rule(&mut self, rule: TranslationRule)
pub fn add_rule(&mut self, rule: TranslationRule)
Appends a rule to the end of the ordered rule set.
Sourcepub fn to_lino(&self) -> String
pub fn to_lino(&self) -> String
Serializes this rule set through the existing canonical LiNo network format.
Sourcepub fn from_lino(text: &str) -> Result<Self, TranslationRuleSetLoadError>
pub fn from_lino(text: &str) -> Result<Self, TranslationRuleSetLoadError>
Loads a rule set from LiNo text produced by TranslationRuleSet::to_lino.
Sourcepub fn statehood_demo_lino() -> &'static str
pub fn statehood_demo_lino() -> &'static str
LiNo text for the built-in statehood demo rule set.
Sourcepub fn statehood_demo() -> Self
pub fn statehood_demo() -> Self
Loads the statehood demo from its LiNo rule-set representation.